@@ -7,7 +7,6 @@ workers.
 import os
 import math
 import time
-import shutil
 import threading
 import heapq
 from contextlib import ExitStack
@@ -16,7 +15,7 @@ import botocore
 import WDL
 import WDL.runtime.task_container
 import WDL.runtime._statusbar
-from WDL._util import PygtailLogger
+from WDL._util import PygtailLogger, rmtree_atomic, symlink_force
 from WDL._util import StructuredLogMessage as _
 from ._util import (
     detect_aws_region,
@@ -145,8 +144,8 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
         # Since we aren't virtualizing the in-container paths as noted above, always use the same
         # working directory on task retries, instead of the base class behavior of appending the
         # try counter (on the host side). This loses some robustness to a split-brain condition
-        # where the previous try is actually still running when we start the retry. We'll assume
-        # Batch prevents that.
+        # where the previous try is actually still running when we start the retry.
+        # (see also retry_wait)
         return os.path.join(self.host_dir, "work")
 
     def host_stdout_txt(self):
@@ -156,7 +155,21 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
         return os.path.join(self.host_dir, "stderr.txt")
 
     def reset(self, logger) -> None:
-        shutil.rmtree(self.host_work_dir())
+        cooldown = (
+            self.cfg.get_float("aws", "retry_wait")
+            if self.cfg.has_option("aws", "retry_wait")
+            else 0.0
+        )
+        if cooldown > 0.0:
+            logger.info(
+                _(
+                    "waiting to retry per configuration [aws] retry_wait",
+                    seconds=cooldown,
+                )
+            )
+            time.sleep(cooldown)
+
+        rmtree_atomic(self.host_work_dir())
         super().reset(logger)
 
     def _run(self, logger, terminating, command):
@@ -223,7 +236,7 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
                 "command": [
                     "/bin/bash",
                     "-c",
-                    f"cd {self.container_dir}/work && bash ../command >> ../stdout.txt 2> >(tee -a ../stderr.txt >&2)",
+                    f"cd {self.container_dir}/work && bash ../command >> ../stdout.txt 2> >(tee -a ../stderr.txt >&2) && sync",
                 ],
                 "resourceRequirements": [
                     {"type": "VCPU", "value": str(vcpu)},
@@ -320,7 +333,7 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
             if link_dn not in link_dirs_made:
                 os.makedirs(link_dn)
                 link_dirs_made.add(link_dn)
-            os.symlink(host_fn, container_fn)
+            symlink_force(host_fn, container_fn)
 
         return volumes, mount_points
 
@@ -357,7 +370,7 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
                     # TODO: base TaskContainer should handle this, for separation of concerns
                     cleanup.enter_context(
                         WDL.runtime._statusbar.task_running(
-                            self.runtime_values.get("cpu", 0),
+                            self.runtime_values.get("cpu", 1),
                             self.runtime_values.get("memory_reservation", 0),
                         )
                     )
@@ -399,9 +412,7 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
             if terminating():
                 aws_batch.terminate_job(jobId=job_id, reason="terminated by miniwdl")
                 raise WDL.runtime.Terminated(
-                    quiet=not self._observed_states.difference(
-                        {"SUBMITTED", "PENDING", "RUNNABLE", "STARTING"}
-                    )
+                    quiet=not self._observed_states.difference({"SUBMITTED", "PENDING", "RUNNABLE"})
                 )
         return exit_code
 
